@@ -42,8 +42,8 @@ with requests.Session() as session:
     def info(message, event_time_required=False):
         installed_packages = [{d.project_name: d.version} for d in pkg_resources.working_set]
         eventTime = datetime.now().strftime("%m/%d/%Y, %H:%M:%S") if event_time_required else None
-        sourceFilePath = sys._getframe().f_code
-        methodName = sys._getframe(1).f_code.co_name
+        sourceFilePath = jsonpickle.encode(sys._getframe().f_code)
+        methodName = jsonpickle.encode(sys._getframe(1).f_code.co_name)
 
         detail = [
             PayloadDetail(
@@ -83,8 +83,8 @@ with requests.Session() as session:
         message = jsonpickle.encode(occurred_error)
         installed_packages = [{d.project_name: d.version} for d in pkg_resources.working_set]
         eventTime = datetime.now().strftime("%m/%d/%Y, %H:%M:%S") if event_time_required else None
-        sourceFilePath = sys._getframe().f_code
-        methodName = sys._getframe(1).f_code.co_name
+        sourceFilePath = jsonpickle.encode(sys._getframe().f_code)
+        methodName = jsonpickle.encode(sys._getframe(1).f_code.co_name)
 
         detail = [
             PayloadDetail(
